#' @title cbind_XStringSetList
#' @name cbind_XStringSetList
#' @description Helper function which cbind a list of \code{XStringSet}
#' into \code{XStringSet}.
#' @param x list of \code{XStringSet}
#' @param type type of \code{XStringSet} [default: DNAStringSet]
#' @param name name
#' @importFrom Biostrings DNAString DNAStringSet AAString AAStringSet
#' readDNAStringSet readAAStringSet writeXStringSet width subseq translate
#' @examples
#' ##load example sequence data
#' data("mousePRDM9", package="repeatR")
#' myRepPattern<-"PY"
#' myRepLength<-84
#' mousePRDM9.random<-sample(mousePRDM9, 4)
#' mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
#'     myRepPattern, myRepLength)
#' repeatR::cbind_XStringSetList(mousePRDM9.random.split$cds,
#'     type="DNAStringSet")
#' repeatR::cbind_XStringSetList(mousePRDM9.random.split$aa,
#'     type="AAStringSet")
#' repeatR::collapse_XStringSetList(repeatR::cbind_XStringSetList(
#'     mousePRDM9.random.split$cds, type="DNAStringSet"))
#' repeatR::collapse_XStringSetList(repeatR::cbind_XStringSetList(
#'     mousePRDM9.random.split$aa, type="AAStringSet"))
#' @export cbind_XStringSetList
#' @author Kristian K Ullrich

cbind_XStringSetList<-function(x, type="DNAStringSet"){
    if(type=="DNAStringSet"){
        x_out <- mapply(function(x, i) {
            setNames(Biostrings::DNAStringSet(paste(as.character(x),
                collapse="")), i)
        }, x, names(x))
    }
    if(type=="AAStringSet"){
        x_out <- mapply(function(x, i) {
            setNames(AAStringSet(paste(as.character(x), collapse="")), i)
        }, x, names(x))
      }
    return(x_out)
}
