#' @title collapse_XStringSetList
#' @name collapse_XStringSetList
#' @description Helper function which collapses a list of \code{XStringSet}
#' into a single \code{XStringSet}.
#' @param x \code{XStringSet}
#' @importFrom Biostrings DNAString DNAStringSet AAString AAStringSet
#' readDNAStringSet readAAStringSet writeXStringSet width subseq translate
#' @examples
#' ##load example sequence data
#' data("mousePRDM9", package="repeatR")
#' myRepPattern<-"PY"
#' myRepLength<-84
#' mousePRDM9.random<-sample(mousePRDM9, 20)
#' mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
#'     myRepPattern, myRepLength)
#' repeatR::collapse_XStringSetList(mousePRDM9.random.split$cds)
#' @export collapse_XStringSetList
#' @author Kristian K Ullrich

collapse_XStringSetList<-function(x){
    tmp <- x
    names(tmp) <- NULL
    return(do.call(c, tmp))
}
