#' @title hamming
#' @name hamming
#' @description This function calculates pairwise string hamming distances.
#' @param X \code{DNAStringSet}
#' @param Y \code{DNAStringSet}
#' @references Vara C et al. (2019) PRDM9 Diveristy at Fine Geographical Scale
#' Reveals Contrasting Evolutionary Patterns and Functional Constraints in
#' Natural Populations of House Mice. \emph{Molecular Biology and Evolution},
#' \bold{36(8)}, 1686-1700.
#' @examples
#' ##load example sequence data
#' data("mousePRDM9", package="repeatR")
#' myRepPattern<-"PY"
#' myRepLength<-84
#' mousePRDM9.random<-sample(mousePRDM9, 20)
#' mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
#'     myRepPattern, myRepLength)
#' ##calculate hamming distance
#' repeatR::hamming(mousePRDM9.random.split$cds[[1]],
#'     mousePRDM9.random.split$cds[[2]])
#' @export hamming
#' @author Kristian K Ullrich

hamming<-function(X, Y) {
    #forked from https://github.com/lucaferretti/RepeatDistance/blob/master/
    #RepeatDistance.R
    if ( missing(Y) ) {
        stopifnot(class(X)=="DNAStringSet")
        X <- t(as.matrix(X))
        uniqs <- unique(as.vector(X))
        U <- X==uniqs[1]
        H <- t(U) %*% U
        for ( uniq in uniqs[-1] ) {
            U <- X==uniq
            H <- H + t(U) %*% U
        }
    } else {
        stopifnot(class(X)=="DNAStringSet")
        stopifnot(class(Y)=="DNAStringSet")
        X <- t(as.matrix(X))
        Y <- t(as.matrix(Y))
        uniqs <- union(X, Y)
        H <- t(X==uniqs[1]) %*% (Y==uniqs[1])
        for ( uniq in uniqs[-1] ) {
            H <- H + t(X==uniq) %*% (Y==uniq)
        }
    }
    return(nrow(X) - H)
}
