% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ListPairwiseDistance.R
\name{ListPairwiseDistance}
\alias{ListPairwiseDistance}
\title{ListPairwiseDistance}
\usage{
ListPairwiseDistance(
  x,
  dist.type = "hamming",
  dna.model = "K80",
  wmut = 1,
  windel = 3.5,
  wslippage = 1.75,
  exclude.pos = NULL,
  post.include = FALSE,
  output.dist = "distance",
  threads = 1
)
}
\arguments{
\item{x}{\code{list} of repeats as \code{DNAStringSet}}

\item{dist.type}{distance calculation method if no gendist matrix is
supplied [default: hamming]}

\item{dna.model}{a character string specifying the evolutionary model to be
used (see \code{ape::dist.dna}) [default: K80]}

\item{wmut}{weight for nucleotide point mutations [default: 1]}

\item{windel}{weight for unit insertions/deletions [default: 3.5]}

\item{wslippage}{weight for single unit duplications [default: 1.75]}

\item{exclude.pos}{positions of the repeat that will be excluded before
distance calculation [default: NULL]}

\item{post.include}{boolean if excluded positions should be added back for
the sequence alignment after distance calculation [default: FALSE]}

\item{output.dist}{specify if either the \code{distance} or
\code{sequence.dist} should be returned (see
\code{repeatR::RepeatAlignment}) [default: distance]}

\item{threads}{number of parallel threads [default: 1]}
}
\description{
Helper function to get all-vs-all repeat distances based on
RepeatAlignment.
}
\examples{
##load example sequence data
data("mousePRDM9", package="repeatR")
myRepPattern<-"PY"
myRepLength<-84
mousePRDM9.random<-sample(mousePRDM9, 20)
mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
    myRepPattern, myRepLength)
##get distance for all-vs-all comparison excluding highly variable sites
dist.mat.hamming.exclude.pos<-repeatR::ListPairwiseDistance(
    x=mousePRDM9.random.split$cds,
    dist.type="hamming",
    wmut=1,
    windel=3.5,
    wslippage=1.75,
    exclude.pos=c(37:39,46:48,55:57),
    post.include=FALSE,
    output.dist="distance")
##calculate bionj tree from resulting distances and write tree in newick
##format
mousePRDM9.random.bionj<-ape::bionj(as.dist(dist.mat.hamming.exclude.pos))
ape::write.tree(mousePRDM9.random.bionj)
plot(mousePRDM9.random.bionj)
}
\references{
Vara C et al. (2019) PRDM9 Diveristy at Fine Geographical Scale
Reveals Contrasting Evolutionary Patterns and Functional Constraints in
Natural Populations of House Mice. \emph{Molecular Biology and Evolution},
\bold{36(8)}, 1686-1700.
}
\seealso{
\code{\link[ape]{dist.dna}}
}
\author{
Kristian K Ullrich
}
