% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ListRepeatAlignment.R
\name{ListRepeatAlignment}
\alias{ListRepeatAlignment}
\title{ListRepeatAlignment}
\usage{
ListRepeatAlignment(
  x,
  y,
  dist.type = "hamming",
  dna.model = "K80",
  wmut = 1,
  windel = 3.5,
  wslippage = 1.75,
  exclude.pos = NULL,
  post.include = FALSE,
  threads = 1
)
}
\arguments{
\item{x}{\code{list} of repeats as \code{DNAStringSet}}

\item{y}{repeat as \code{DNAStringSet}}

\item{dist.type}{distance calculation method if no gendist matrix is
supplied [default: hamming]}

\item{dna.model}{a character string specifying the evolutionary model to be
used (see \code{ape::dist.dna}) [default: K80]}

\item{wmut}{weight for nucleotide point mutations [default: 1]}

\item{windel}{weight for unit insertions/deletions [default: 3.5]}

\item{wslippage}{weight for single unit duplications [default: 1.75]}

\item{exclude.pos}{positions of the repeat that will be excluded before
distance calculation [default: NULL]}

\item{post.include}{boolean if excluded positions should be added back for
the sequence alignment after distance calculation [default: FALSE]}

\item{threads}{number of parallel threads [default: 1]}
}
\description{
Helper function to get all repeat alignments for a list of
repeats against one repeat.
}
\examples{
##load example sequence data
data("mousePRDM9", package="repeatR")
myRepPattern<-"PY"
myRepLength<-84
mousePRDM9.random<-sample(mousePRDM9, 20)
mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
    myRepPattern, myRepLength)
##get the repeat with max number of repeat units
mousePRDM9.random.split.repeat.units<-unlist(lapply(
    mousePRDM9.random.split$cds, length))
max.pos<-which(mousePRDM9.random.split.repeat.units==
    max(mousePRDM9.random.split.repeat.units))
##select one/the longest repeat as the target sequences
target.repeat<-mousePRDM9.random.split$cds[[sample(max.pos,1)]]
##align all repeats in the list to the target repeat
mousePRDM9.random.alg<-repeatR::ListRepeatAlignment(
    mousePRDM9.random.split$cds, target.repeat)
mousePRDM9.random.alg
##change settings as for the RepeatAlignment function
}
\references{
Vara C et al. (2019) PRDM9 Diveristy at Fine Geographical Scale
Reveals Contrasting Evolutionary Patterns and Functional Constraints in
Natural Populations of House Mice. \emph{Molecular Biology and Evolution},
\bold{36(8)}, 1686-1700.
}
\seealso{
\code{\link[ape]{dist.dna}}
}
\author{
Kristian K Ullrich
}
