% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RepeatAlignment.R
\name{RepeatAlignment}
\alias{RepeatAlignment}
\title{RepeatAlignment}
\usage{
RepeatAlignment(
  seq1,
  seq2,
  seq1.name = "seq1",
  seq2.name = "seq2",
  gendist = NULL,
  dist.type = "hamming",
  dna.model = "K80",
  wmut = 1,
  windel = 3.5,
  wslippage = 1.75,
  exclude.pos = NULL,
  post.include = FALSE,
  show.steps = FALSE
)
}
\arguments{
\item{seq1}{\code{DNAStringSet}}

\item{seq2}{\code{DNAStringSet}}

\item{seq1.name}{seq1 name [default: seq1]}

\item{seq2.name}{seq2 name [default: seq2]}

\item{gendist}{pairwise distance matrix of seq1 and seq2 repeats
[default: NULL]}

\item{dist.type}{distance calculation method if no gendist matrix is
supplied [default: hamming]}

\item{dna.model}{a character string specifying the evolutionary model to be
used (see \code{ape::dist.dna}) [default: K80]}

\item{wmut}{weight for nucleotide point mutations [default: 1]}

\item{windel}{weight for unit insertions/deletions [default: 3.5]}

\item{wslippage}{weight for single unit duplications [default: 1.75]}

\item{exclude.pos}{positions of the repeat that will be excluded before
distance calculation [default: NULL]}

\item{post.include}{boolean if excluded positions should be added back for
the sequence alignment after distance calculation [default: FALSE]}
}
\description{
This function calculates genetic distances between complex
repeats as described in \emph{Vara (2019)}.
This function is forked from
\url{github.com/lucaferretti/RepeatDistance/blob/master/RepeatDistance.R}
and adapted to work with \code{Biostrings} objects.
}
\examples{
##load example sequence data
data("mousePRDM9", package="repeatR")
myRepPattern<-"PY"
myRepLength<-84
mousePRDM9.random<-sample(mousePRDM9, 20)
mousePRDM9.random.split<-repeatR::splitRepByPattern(mousePRDM9.random,
    myRepPattern, myRepLength)
##get repeat alignment
repeatR::RepeatAlignment(mousePRDM9.random.split$cds[[1]],
    mousePRDM9.random.split$cds[[2]])
##get repeat alignment and exclude highly variable sites for the distance
##calculation
repeatR::RepeatAlignment(mousePRDM9.random.split$cds[[1]],
    mousePRDM9.random.split$cds[[2]],
    exclude.pos = c(37:39, 46:48, 55:57))
##get repeat alignment, exclude highly variable sites for the distance
##calculation and add them back afterwards
repeatR::RepeatAlignment(mousePRDM9.random.split$cds[[1]],
    mousePRDM9.random.split$cds[[2]],
    exclude.pos = c(37:39, 46:48, 55:57),
    post.include = TRUE)
}
\references{
Vara C et al. (2019) PRDM9 Diveristy at Fine Geographical Scale
Reveals Contrasting Evolutionary Patterns and Functional Constraints in
Natural Populations of House Mice. \emph{Molecular Biology and Evolution},
\bold{36(8)}, 1686-1700.
}
\seealso{
\code{\link[ape]{dist.dna}}
}
\author{
Kristian K Ullrich
}
